@@ -3,7 +3,7 @@ import re
 import datetime
 from decimal import Decimal
 
-def nice_repr(timedelta, display="long"):
+def nice_repr(timedelta, display="long", sep=" "):
     """
     Turns a datetime.timedelta object into a nice string repr.
     
@@ -18,7 +18,7 @@ def nice_repr(timedelta, display="long"):
     
     assert isinstance(timedelta, datetime.timedelta), "First argument must be a timedelta."
     
-    result = ""
+    result = []
     
     weeks = timedelta.days / 7
     days = timedelta.days % 7
@@ -26,7 +26,10 @@ def nice_repr(timedelta, display="long"):
     minutes = (timedelta.seconds % 3600) / 60
     seconds = timedelta.seconds % 60
     
-    if display == 'minimal':
+    if display == "sql":
+        days += weeks * 7
+        return "%i %02i:%02i:%02i" % (days, hours, minutes, seconds)
+    elif display == 'minimal':
         words = ["w", "d", "h", "m", "s"]
     elif display == 'short':
         words = [" wks", " days", " hrs", " min", " sec"]
@@ -38,11 +41,47 @@ def nice_repr(timedelta, display="long"):
     for i in range(len(values)):
         if values[i]:
             if values[i] == 1 and len(words[i]) > 1:
-                result += "%i%s, " % (values[i], words[i].rstrip('s'))
+                result.append("%i%s" % (values[i], words[i].rstrip('s')))
             else:
-                result += "%i%s, " % (values[i], words[i])
+                result.append("%i%s" % (values[i], words[i]))
     
-    return result[:-2]
+    return sep.join(result)
+
+def iso8601_repr(timedelta):
+    """
+    Represent a timedelta as an ISO8601 duration.
+    http://en.wikipedia.org/wiki/ISO_8601#Durations
+
+    >>> from datetime import timedelta as td
+    >>> iso8601_repr(td(days=1, hours=2, minutes=3, seconds=4))
+    'P1DT2HM3S4'
+    """
+    years = timedelta.days / 365
+    weeks = (timedelta.days % 365) / 7
+    days = timedelta.days % 7
+
+    hours = timedelta.seconds / 3600
+    minutes = (timedelta.seconds % 3600) / 60
+    seconds = timedelta.seconds % 60
+
+    formatting = {'P': {'Y': years,
+                        'W': weeks,
+                        'D': days
+                        },
+                  'T': {'H': hours,
+                        'M': minutes,
+                        'S': seconds
+                        }
+                  }
+
+    result = ''
+    for category, subcats  in formatting.items():
+        result += category
+        for format, value in subcats.items():
+            if value:
+                result += '%d%c' % (value, format)
+
+    return result
 
 def parse(string):
     """
@@ -54,7 +93,7 @@ def parse(string):
     datetime.timedelta(2)
     """
     # This is the format we sometimes get from Postgres.
-    d = re.match(r'((?P<days>\d+) days )?(?P<hours>\d+):'
+    d = re.match(r'((?P<days>\d+) days? )?(?P<hours>\d+):'
                  r'(?P<minutes>\d+)(:(?P<seconds>\d+))?',
                  unicode(string))
     if d: 
